@@ -19,10 +19,6 @@
 #include<libnet.h>
 #include<pcap.h>
 #include "pcap-int.h"
-#include<net/if_arp.h>
-#include<netinet/if_ether.h>
-#include<netinet/ip.h>
-#include<netinet/tcp.h>
 // custom librairies
 #include "gps.h"
 #include "services.h"
@@ -44,7 +40,7 @@ port_elt *tab_port=NULL;
 devlist *dl=NULL;
 netdev dev;
 struct pcap *descr=NULL;
-u_char dst_mac[ETH_ALEN];
+u_char dst_mac[GPS_ETH_ALEN];
 char errbuf[GPS_ERRBUF_SIZE];
 extern char *optarg;
 
@@ -94,10 +90,10 @@ int main(int argc, char **argv)
 	int i_ip=0, max_retries, max_timeout=0, verbose=0, nbpkt=0, serv_scan=1;
 	struct libnet_link_int *interface=NULL;
 	struct pcap_pkthdr phdr;
-	struct ether_header *ehdr;
-	struct ether_arp *ahdr, duplic;
-	struct ip *ihdr;
-	struct tcphdr *thdr;
+	struct libnet_ethernet_hdr *ehdr;
+	struct libnet_arp_hdr *ahdr, duplic;
+	struct libnet_ip_hdr *ihdr;
+	struct libnet_tcp_hdr *thdr;
 	struct timeval tv;
 	sock_elt sckelt;
 	netdev *nd;
@@ -156,7 +152,7 @@ int main(int argc, char **argv)
 				strncpy(str_ip, optarg, BUFSIZ-1);
 				str_ip[BUFSIZ-1]='\0';
 				if((dst_ip=libnet_name_resolve(str_ip, LIBNET_RESOLVE))==-1)
-					libnet_error(LIBNET_ERR_FATAL, "libnet_name_resolve: invalid target: %s\n", str_ip);
+					libnet_error(LIBNET_ERR_FATAL, "libnet_name_resolve: not able to reslove: %s\n", str_ip);
 				break;
 			case 'p':
 				// first_port and last_port
@@ -277,7 +273,7 @@ int main(int argc, char **argv)
 				spoofing=IP_SPOOF;
 			}
 			if(fragment==OVERLAP_FRAG) {
-				libnet_error(LIBNET_ERR_WARNING, "Fragment overlapping requires spoofing at physical level, and this is not compliant with scaning through loopback\n");
+				libnet_error(LIBNET_ERR_WARNING, "Fragment overlapping requires spoofing at physical level, and it is not compliant with scaning through loopback\n");
 				fragment=NO_FRAG;
 			}
 		} else {
@@ -287,7 +283,8 @@ int main(int argc, char **argv)
 				dev.name[IFNAMSIZ-1]='\0';
 			}
 			else libnet_error(LIBNET_ERR_FATAL, "All attemps to get a suitable network device failed. You should try the -i option to specify the device to use.\n");
-			if(strncmp("et", dev.name, 2)) error("Device %s is not yet supported by GPS.", -1);
+			if(strncmp("et", dev.name, 2) && strncmp("lo", dev.name, 2))
+				error("Device %s is not yet supported by GPS.", -1);
 		}
 	}
 	fprintf(stdout, "Network device: %s\n", dev.name);
@@ -325,23 +322,21 @@ int main(int argc, char **argv)
 	// if MAC spoofing is activated, get the MAC address of
 	// the host or gateway to which send the ethernet trames
 	if(spoofing==MAC_SPOOF) {
-		if(verbose) fprintf(stdout, "Searching for the destination MAC address\n");
+		if(verbose) fprintf(stdout, "Searching for the destination MAC address..\n");
 		if(onlocalnet) {
 			if(get_mac(dst_ip, dst_mac, dev.name)==-1)
 				if(send_ARP_request(dev.name, &src_ip[0].ip, &dst_ip, src_ip[0].ea, dst_mac)==-1)
 					libnet_error(LIBNET_ERR_FATAL, "Not able to get the MAC address of host: %s\n", libnet_host_lookup(dst_ip, LIBNET_RESOLVE));
 		} else {
-			// this is not very smartly handled, as far as get_gateway_ip returns
-			// the first gateway IP it finds in FROUTE (/proc/net/route)
-			if((ip=get_gateway_ip(FROUTE))==-1)
-				libnet_error(LIBNET_ERR_FATAL, "get_gateway_ip: not able to find a gateway\n");
+			if((ip=get_gateway_ip(dst_ip))==-1)
+				libnet_error(LIBNET_ERR_FATAL, "get_gateway_ip: not able to find a suitable gateway\n");
 			if(get_mac(ip, dst_mac, dev.name)==-1)
 				if(send_ARP_request(dev.name, &src_ip[0].ip, &ip, src_ip[0].ea, dst_mac)==-1)
-					libnet_error(LIBNET_ERR_FATAL, "Not able to get the MAC address of host: %s\n", libnet_host_lookup(ip, LIBNET_RESOLVE));
+					libnet_error(LIBNET_ERR_FATAL, "Not able to get the MAC address of the gateway: %s. You should add the -Sip option to fix the problem.\n", libnet_host_lookup(ip, LIBNET_RESOLVE));
 		}
 		if(verbose>1) {
 			fprintf(stdout, "Destination MAC address: ");
-			for(i=0; i<ETH_ALEN; i++) fprintf(stdout, "%x%c", dst_mac[i], (i==ETH_ALEN-1)?'\n':':');
+			for(i=0; i<GPS_ETH_ALEN; i++) fprintf(stdout, "%x%c", dst_mac[i], (i==GPS_ETH_ALEN-1)?'\n':':');
 		}
 	}
 
@@ -423,10 +418,10 @@ int main(int argc, char **argv)
 			// packet filter
 			if(localhost) // scaning localhost through lo
 			{
-				ihdr=(struct ip *)(packet+4);
+				ihdr=(struct libnet_ip_hdr *)(packet+4);
 				if(ihdr->ip_src.s_addr==dst_ip && ihdr->ip_dst.s_addr==dst_ip && !(ihdr->ip_off & ~ntohs(IP_DF)) && ihdr->ip_p==IPPROTO_TCP)
 				{
-					thdr=(struct tcphdr *)((u_char *)ihdr+4*ihdr->ip_hl);
+					thdr=(struct libnet_tcp_hdr *)((u_char *)ihdr+4*ihdr->ip_hl);
 					// test packet flags
 					i=0;
 					switch(scan_type)
@@ -477,41 +472,41 @@ int main(int argc, char **argv)
 			}
 			else
 			{
-				ehdr=(struct ether_header *)packet;
+				ehdr=(struct libnet_ethernet_hdr *)packet;
 				switch(ntohs(ehdr->ether_type))
 				{
 					case ETHERTYPE_ARP: // ARP packet
-						ahdr=(struct ether_arp *)((u_char *)ehdr + ETHER_HDR_LEN);
+						ahdr=(struct libnet_arp_hdr *)((u_char *)ehdr + ETHER_HDR_LEN);
 						// break if it is not an ARP request
-						if(ntohs(ahdr->ea_hdr.ar_op)!=ARPOP_REQUEST) break;
+						if(ntohs(ahdr->ar_op)!=ARPOP_REQUEST) break;
 						// break if the ARP request do not concern
 						// the hosts we pretend to be
-						if((j=search_src_ip(*((u_int32_t *)ahdr->arp_tpa)))==-1) break;
+						if((j=search_src_ip(*((u_int32_t *)ahdr->ar_tpa)))==-1) break;
 						// we have to reply this ARP request
 						duplic=*ahdr;
-						ahdr->ea_hdr.ar_op=ntohs(ARPOP_REPLY);
+						ahdr->ar_op=ntohs(ARPOP_REPLY);
 						// build the spoofed ARP reply
-						for(i=0; i<ETH_ALEN; i++) // exchange ARP addresses
+						for(i=0; i<GPS_ETH_ALEN; i++) // exchange ARP addresses
 						{
-							ahdr->arp_sha[i]=ehdr->ether_shost[i]=(u_int8_t)src_ip[j].ea[i];
-							ahdr->arp_tha[i]=ehdr->ether_dhost[i]=duplic.arp_sha[i];
+							ahdr->ar_sha[i]=ehdr->ether_shost[i]=(u_int8_t)src_ip[j].ea[i];
+							ahdr->ar_tha[i]=ehdr->ether_dhost[i]=duplic.ar_sha[i];
 						}
 						for(i=0; i<4; i++) // exchange IP adresses
 						{
-							ahdr->arp_spa[i]=duplic.arp_tpa[i];
-							ahdr->arp_tpa[i]=duplic.arp_spa[i];
+							ahdr->ar_spa[i]=duplic.ar_tpa[i];
+							ahdr->ar_tpa[i]=duplic.ar_spa[i];
 						}
 						// send the fake ARP reply
-						if(libnet_write_link_layer(interface, dev.name, (u_char *)packet, ETHER_HDR_LEN + sizeof(struct ether_arp))==-1)
+						if(libnet_write_link_layer(interface, dev.name, (u_char *)packet, ETHER_HDR_LEN + sizeof(struct libnet_arp_hdr))==-1)
 							libnet_error(LIBNET_ERR_WARNING, "libnet_write_link layer failed\n");
 						break;
 					case ETHERTYPE_IP: // IP packet
-						ihdr=(struct ip *)((u_char *)ehdr + ETHER_HDR_LEN);
+						ihdr=(struct libnet_ip_hdr *)((u_char *)ehdr + ETHER_HDR_LEN);
 						// break if the packet do not come from the target host
 						// or if it is not addressed to the hosts we pretend to be
 						// or if it is fragmented, or if it is not a TCP packet
 						if(ihdr->ip_src.s_addr!=dst_ip || ((scan_type!=FWRD_SCAN) ? (search_src_ip(ihdr->ip_dst.s_addr)==-1) : (ihdr->ip_dst.s_addr!=src_ip[i_ip].ip)) || (ihdr->ip_off & ~ntohs(IP_DF)) || ihdr->ip_p!=IPPROTO_TCP) break;
-						thdr=(struct tcphdr *)((u_char *)ihdr + 4 * ihdr->ip_hl);
+						thdr=(struct libnet_tcp_hdr *)((u_char *)ihdr + 4 * ihdr->ip_hl);
 						// test packet flags
 						i=0;
 						switch(scan_type)
@@ -761,7 +756,7 @@ int main(int argc, char **argv)
 void get_ea(char *ea, int rs)
 {
 	int i;
-	for(i=0; i<ETH_ALEN; i++) ea[i]=(u_char)libnet_get_prand(rs);
+	for(i=0; i<GPS_ETH_ALEN; i++) ea[i]=(u_char)libnet_get_prand(rs);
 }
 
 void init_port(int i, u_int16_t port)
@@ -995,7 +990,7 @@ void ethernet_packet_generator(int scan_speed)
 	int rflags[NB_RAND_FLAGS]={0, TH_FIN, TH_PUSH, TH_URG, TH_FIN|TH_PUSH, TH_FIN|TH_URG, TH_PUSH|TH_URG, TH_FIN|TH_PUSH|TH_URG};
 	char *packets=NULL, *frag_packets=NULL;
 	u_char *src_mac=src_ip[0].ea;
-	struct tcphdr *thdr;
+	struct libnet_tcp_hdr *thdr;
 	struct libnet_link_int *interface;
 	u_int32_t rsrc_ip=src_ip[0].ip;
 	sock_elt sckelt;
@@ -1083,7 +1078,7 @@ void ethernet_packet_generator(int scan_speed)
 					if(libnet_do_checksum(frag_packets+offset+GPS_ETH_H, IPPROTO_IP, GPS_IP_H)==-1)
 						libnet_error(LIBNET_ERR_FATAL, "libnet_do_checksum failed\n");
 					// reset the first frag's TCP flags
-					thdr=(struct tcphdr *)(packets+offset+GPS_ETH_H+GPS_IP_H);
+					thdr=(struct libnet_tcp_hdr *)(packets+offset+GPS_ETH_H+GPS_IP_H);
 					thdr->th_flags=TH_NULL;
 					// send them
 					libnet_write_link_layer(interface, dev.name, packets+offset, GPS_TRAME-4);
