@@ -3,20 +3,23 @@
 
 #include<libnet.h>
 #include<pcap.h>
-#include<arpa/inet.h>
+#include<sys/types.h>
 #include<time.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #ifdef VERSION
 #define GPS_VERSION VERSION
 #else
-#define GPS_VERSION "0.8.0"
+#define GPS_VERSION "0.8.1"
 #endif
 
 
+// NULL flag
 #define TH_NULL 0
 
-
 // spoofing options
 #define MAC_SPOOF 1
 #define IP_SPOOF  0
@@ -26,7 +29,7 @@
 #define FIN_SCAN  TH_FIN
 #define ACK_SCAN  TH_ACK
 #define XMAS_SCAN TH_FIN|TH_URG|TH_PUSH
-#define NULL_SCAN  0
+#define NULL_SCAN TH_NULL
 #define RAND_SCAN -1
 #define FWRD_SCAN -2
 
@@ -42,18 +45,20 @@
 #define GPS_IP_H  (LIBNET_IP_H)
 #define GPS_TCP_H (LIBNET_TCP_H)
 #define GPS_TRAME (GPS_ETH_H+GPS_IP_H+GPS_TCP_H)
-
-typedef struct
-{
-	u_int32_t ip;		// IP address
-	u_char ea[ETH_ALEN];	// ethernet address
-} arp_elt;
+#define GPS_ETH_ALEN (ETHER_ADDR_LEN)
 
 #define TIMEVAL_MSEC_DIFF(a, b) ((((a).tv_sec-(b).tv_sec)*1000)+(((a).tv_usec-(b).tv_usec)/1000))
 
+
+typedef struct
+{
+	u_int32_t ip;			// IP address
+	u_char ea[GPS_ETH_ALEN];	// ethernet address
+} arp_elt;
+
 typedef struct 
 {
-	u_int32_t ip;		// src_ip GPS used
+	u_int32_t ip;		// src_ip GPS uses
 	u_int16_t port;		// dst_port
 	u_int16_t src_port;	// src_port
 	int seq;		// seq nb
