@@ -1,23 +1,27 @@
 #ifndef ROUTE_H
 #define ROUTE_H
 
-#include<sys/types.h>
 #include<net/if.h>
-#include<netinet/in.h>
+#include "gps.h"
 
-typedef struct
-{
+#define DELIM " \t\n"
+#define FROUTE "/proc/net/route"
+
+typedef struct {
 	u_int32_t ip;
 	u_int32_t netmask;
 	char name[IFNAMSIZ];
 } netdev;
 
-typedef struct
-{
+typedef struct {
 	int nb;
 	netdev *dev_list;
 } devlist;
 
+typedef struct {
+	char ifname[IFNAMSIZ];
+	u_int32_t gateway;
+} route_elt;
 
 /*
  * I created this structure to replace struct ifreq.
@@ -59,5 +63,7 @@ devlist *get_localdevs();
 void free_devlist(devlist *dl);
 int islocalhost(devlist *dl, u_int32_t ip);
 netdev *get_suitable_dev(devlist *dl, u_int32_t target_ip);
+u_int32_t get_gateway_ip(u_int32_t dstip);
+route_elt *get_route(u_int32_t dstip);
 
 #endif
