@@ -1,10 +1,6 @@
 #include<libnet.h>
 #include<pcap.h>
 #include "pcap-int.h"
-#include<net/if_arp.h>
-#include<netinet/if_ether.h>
-#include<netinet/ip.h>
-#include<netinet/tcp.h>
 
 #include "timeout.h"
 #include "gps.h"
@@ -15,10 +11,10 @@ int ethernet_eval_timeout(char *dev, int rseed, int verbose, u_int32_t srcip, u_
 	struct pcap *pdescr;
 	struct pcap_pkthdr phdr;
 	struct libnet_link_int *interface;
-	struct ether_header *ehdr;
-	struct ether_arp *ahdr, duplic;
-	struct ip *ihdr;
-	struct tcphdr *thdr;
+	struct libnet_ethernet_hdr *ehdr;
+	struct libnet_arp_hdr *ahdr, duplic;
+	struct libnet_ip_hdr *ihdr;
+	struct libnet_tcp_hdr *thdr;
 	char ebuf[GPS_ERRBUF_SIZE];
 	const u_char *packet;
 	u_char *my_packet;
@@ -56,32 +52,32 @@ int ethernet_eval_timeout(char *dev, int rseed, int verbose, u_int32_t srcip, u_
 		}
 		if((packet=(u_char *)pcap_next(pdescr, &phdr)))
 		{
-			ehdr=(struct ether_header *)packet;
+			ehdr=(struct libnet_ethernet_hdr *)packet;
 			switch(ntohs(ehdr->ether_type))
 			{
 				case ETHERTYPE_ARP:
-					ahdr=(struct ether_arp*)((u_char *)ehdr+ETHER_HDR_LEN);
-					if(ntohs(ahdr->ea_hdr.ar_op)!=ARPOP_REQUEST) break;
-					if(*(u_int32_t *)ahdr->arp_tpa!=srcip) break;
+					ahdr=(struct libnet_arp_hdr *)((u_char *)ehdr+ETHER_HDR_LEN);
+					if(ntohs(ahdr->ar_op)!=ARPOP_REQUEST) break;
+					if(*(u_int32_t *)ahdr->ar_tpa!=srcip) break;
 					duplic=*ahdr;
-					ahdr->ea_hdr.ar_op=ntohs(ARPOP_REPLY);
-					for(i=0; i<ETH_ALEN; i++)
+					ahdr->ar_op=ntohs(ARPOP_REPLY);
+					for(i=0; i<GPS_ETH_ALEN; i++)
 					{
-						ahdr->arp_sha[i]=ehdr->ether_shost[i]=src_mac[i];
-						ahdr->arp_tha[i]=ehdr->ether_dhost[i]=duplic.arp_sha[i];
+						ahdr->ar_sha[i]=ehdr->ether_shost[i]=src_mac[i];
+						ahdr->ar_tha[i]=ehdr->ether_dhost[i]=duplic.ar_sha[i];
 					}
 					for(i=0; i<4; i++)
 					{
-						ahdr->arp_spa[i]=duplic.arp_tpa[i];
-						ahdr->arp_tpa[i]=duplic.arp_spa[i];
+						ahdr->ar_spa[i]=duplic.ar_tpa[i];
+						ahdr->ar_tpa[i]=duplic.ar_spa[i];
 					}
-					if(libnet_write_link_layer(interface, dev, (u_char *)packet, ETHER_HDR_LEN+sizeof(struct ether_arp))==-1)
+					if(libnet_write_link_layer(interface, dev, (u_char *)packet, ETHER_HDR_LEN+sizeof(struct libnet_arp_hdr))==-1)
 						libnet_error(LIBNET_ERR_WARNING, "libnet_write_link_layer failed\n");
 					break;
 				case ETHERTYPE_IP:
-					ihdr=(struct ip *)((u_char *)ehdr+ETHER_HDR_LEN);
+					ihdr=(struct libnet_ip_hdr *)((u_char *)ehdr+ETHER_HDR_LEN);
 					if(ihdr->ip_src.s_addr!=dstip || ihdr->ip_dst.s_addr!=srcip || ihdr->ip_p!=IPPROTO_TCP || (ihdr->ip_off & ~ntohs(IP_DF))) break;
-					thdr=(struct tcphdr *)((u_char *)ihdr+4*ihdr->ip_hl);
+					thdr=(struct libnet_tcp_hdr *)((u_char *)ihdr+4*ihdr->ip_hl);
 					if(!(thdr->th_flags & TH_RST) || ntohs(thdr->th_sport)!=pingport) break;
 					gettimeofday(&tv1, NULL);
 					if(!(i=TIMEVAL_MSEC_DIFF(tv1, tv2))) i++;
@@ -127,10 +123,10 @@ int ip_eval_timeout(char *dev, int rseed, int verbose, u_int32_t srcip, u_int32_
 	struct pcap *pdescr;
 	struct pcap_pkthdr phdr;
 	struct libnet_link_int *interface;
-	struct ether_header *ehdr;
-	struct ether_arp *ahdr, duplic;
-	struct ip *ihdr;
-	struct tcphdr *thdr;
+	struct libnet_ethernet_hdr *ehdr;
+	struct libnet_arp_hdr *ahdr, duplic;
+	struct libnet_ip_hdr *ihdr;
+	struct libnet_tcp_hdr *thdr;
 	char ebuf[GPS_ERRBUF_SIZE];
 	const u_char *packet;
 	u_char *my_packet;
@@ -169,32 +165,32 @@ int ip_eval_timeout(char *dev, int rseed, int verbose, u_int32_t srcip, u_int32_
 		}
 		if((packet=(u_char *)pcap_next(pdescr, &phdr)))
 		{
-			ehdr=(struct ether_header *)packet;
+			ehdr=(struct libnet_ethernet_hdr *)packet;
 			switch(ntohs(ehdr->ether_type))
 			{
 				case ETHERTYPE_ARP:
-					ahdr=(struct ether_arp*)((u_char *)ehdr+ETHER_HDR_LEN);
-					if(ntohs(ahdr->ea_hdr.ar_op)!=ARPOP_REQUEST) break;
-					if(*(u_int32_t *)ahdr->arp_tpa!=srcip) break;
+					ahdr=(struct libnet_arp_hdr *)((u_char *)ehdr+ETHER_HDR_LEN);
+					if(ntohs(ahdr->ar_op)!=ARPOP_REQUEST) break;
+					if(*(u_int32_t *)ahdr->ar_tpa!=srcip) break;
 					duplic=*ahdr;
-					ahdr->ea_hdr.ar_op=ntohs(ARPOP_REPLY);
-					for(i=0; i<ETH_ALEN; i++)
+					ahdr->ar_op=ntohs(ARPOP_REPLY);
+					for(i=0; i<GPS_ETH_ALEN; i++)
 					{
-						ahdr->arp_sha[i]=ehdr->ether_shost[i]=src_mac[i];
-						ahdr->arp_tha[i]=ehdr->ether_dhost[i]=duplic.arp_sha[i];
+						ahdr->ar_sha[i]=ehdr->ether_shost[i]=src_mac[i];
+						ahdr->ar_tha[i]=ehdr->ether_dhost[i]=duplic.ar_sha[i];
 					}
 					for(i=0; i<4; i++)
 					{
-						ahdr->arp_spa[i]=duplic.arp_tpa[i];
-						ahdr->arp_tpa[i]=duplic.arp_spa[i];
+						ahdr->ar_spa[i]=duplic.ar_tpa[i];
+						ahdr->ar_tpa[i]=duplic.ar_spa[i];
 					}
-					if(libnet_write_link_layer(interface, dev, (u_char *)packet, ETHER_HDR_LEN+sizeof(struct ether_arp))==-1)
+					if(libnet_write_link_layer(interface, dev, (u_char *)packet, ETHER_HDR_LEN+sizeof(struct libnet_arp_hdr))==-1)
 						libnet_error(LIBNET_ERR_WARNING, "libnet_write_link_layer failed\n");
 					break;
 				case ETHERTYPE_IP:
-					ihdr=(struct ip *)((u_char *)ehdr+ETHER_HDR_LEN);
+					ihdr=(struct libnet_ip_hdr *)((u_char *)ehdr+ETHER_HDR_LEN);
 					if(ihdr->ip_src.s_addr!=dstip || ihdr->ip_dst.s_addr!=srcip || ihdr->ip_p!=IPPROTO_TCP || (ihdr->ip_off & ~ntohs(IP_DF))) break;
-					thdr=(struct tcphdr *)((u_char *)ihdr+4*ihdr->ip_hl);
+					thdr=(struct libnet_tcp_hdr *)((u_char *)ihdr+4*ihdr->ip_hl);
 					if(!(thdr->th_flags & TH_RST) || ntohs(thdr->th_sport)!=pingport) break;
 					gettimeofday(&tv1, NULL);
 					if(!(i=TIMEVAL_MSEC_DIFF(tv1, tv2))) i++;
